/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
#define RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1

// Meta data item definition version
const char* const RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const char* const RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
typedef struct MetaDataItemInfo
{
    const char*   name;
    const char*   title;
    const char*   description;
    unsigned char status;
    const char*   schema;
    const char*   example;
} MetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"],\"title\":\"Angular "
    "Notch Filter\",\"properties\":{\"amplitude_mean\":{\"items\":{\"type\":\"number\""
    "},\"type\":\"array\",\"description\":\"Mean amplitude [dB]\"},\"range_mean\":{\"i"
    "tems\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Mean range [m]\"}"
    ",\"angle\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Angl"
    "e [deg]\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":"
    "\"object\",\"description\":\"Angular notch filter parameters for window "
    "glass echoes\"}"
    ,
    /* example: */
    "{\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,2.850913,2.7209"
    "13,2.680913,2.610913,2.530913,2.570913,2.570913],\"range_mean\":[0.094,0"
    ".094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475],\""
    "angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"temperature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"am"
    "sl\",\"group_velocity\",\"attenuation\",\"wavelength\"],\"title\":\"Atmospheric "
    "Parameters\",\"properties\":{\"pressure_sl\":{\"type\":\"number\",\"description\""
    ":\"Atmospheric pressure at sea level "
    "[mbar]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group velocity "
    "of laser beam "
    "[m/s]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength"
    " [nm]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean sea "
    "level (AMSL) [m]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure"
    " along measurment path [mbar]\"}},\"$schema\":\"http://json-schema.org/dra"
    "ft-04/schema#\",\"type\":\"object\",\"description\":\"Atmospheric parameters\"}"
    ,
    /* example: */
    "{\"pressure_sl\":970,\"temperature\":7,\"rel_humidity\":63,\"group_velocity\":"
    "299711000.0,\"attenuation\":0.028125,\"wavelength\":1550,\"amsl\":0,\"pressur"
    "e\":970}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"beam_exit_diameter\",\"beam_divergence\"],\"title\":\"Beam Geo"
    "metry\",\"properties\":{\"beam_exit_diameter\":{\"minimum\":0,\"type\":\"number\""
    ",\"exclusiveMinimum\":false,\"description\":\"Beam width at exit aperture ["
    "m]\"},\"beam_divergence\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\""
    ":false,\"description\":\"Beam divergence in far field [rad]\"}},\"$schema\":"
    "\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"description"
    "\":\"Laser beam geometry details\"}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"types\"],\"title\":\"Control Object Catalog\",\"properties\":{\""
    "types\":{\"items\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/recta"
    "ngle\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/definitions"
    "/chevron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/definitio"
    "ns/cylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/r"
    "ound_corner_cube_prism\"}]},\"type\":\"array\",\"uniqueItems\":true}},\"$schem"
    "a\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"definiti"
    "ons\":{\"cylinder\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/comm"
    "on\"},{\"type\":\"object\",\"required\":[\"shape\",\"diameter\",\"height\"],\"proper"
    "ties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"cylinder\"],\"description\":\"sha"
    "pe identifier\"},\"height\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimu"
    "m\":true,\"description\":\"height in meters\"},\"diameter\":{\"minimum\":0,\"typ"
    "e\":\"number\",\"exclusiveMinimum\":true,\"description\":\"diameter in "
    "meters\"}},\"description\":\"cylinder specific properties\"}],\"description\""
    ":\"cylinder\"},\"circular_disk\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/defi"
    "nitions/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"diameter\"],\"pro"
    "perties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"circular_disk\"],\"descripti"
    "on\":\"shape "
    "identifier\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"},\"diameter\":{\"minimum\":0,\""
    "type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"diameter in "
    "meters\"}},\"description\":\"circular disk specific "
    "properties\"}],\"description\":\"circular disk\"},\"sphere\":{\"type\":\"object\""
    ",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"required\":"
    "[\"shape\",\"diameter\"],\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"s"
    "phere\"],\"description\":\"shape identifier\"},\"diameter\":{\"minimum\":0,\"typ"
    "e\":\"number\",\"exclusiveMinimum\":true,\"description\":\"diameter in "
    "meters\"}},\"description\":\"sphere specific properties\"}],\"description\":\""
    "sphere\"},\"common\":{\"type\":\"object\",\"required\":[\"name\",\"shape\"],\"proper"
    "ties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\",\"checkerboard2x2\","
    "\"chevron\",\"circular_disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism"
    "\"],\"description\":\"shape "
    "identifier\"},\"description\":{\"type\":\"string\",\"description\":\"string "
    "describing the object\"},\"surface_type\":{\"type\":\"string\",\"enum\":[\"retro"
    "_reflective_foil\",\"diffuse\"],\"description\":\"surface material "
    "type\"},\"name\":{\"minLength\":3,\"type\":\"string\",\"description\":\"unique "
    "type identifier\"}},\"description\":\"common object properties\"},\"rectangl"
    "e\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\""
    "object\",\"required\":[\"shape\",\"length\",\"width\"],\"properties\":{\"shape\":{\""
    "type\":\"string\",\"enum\":[\"rectangle\"]},\"width\":{\"minimum\":0,\"type\":\"numb"
    "er\",\"exclusiveMinimum\":true,\"description\":\"width in meters\"},\"length\":"
    "{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"le"
    "ngth in meters\"}},\"description\":\"rectangle specific properties\"}],\"des"
    "cription\":\"rectangle\"},\"chevron\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/"
    "definitions/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"outside_edg"
    "e_length\",\"thickness\"],\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":["
    "\"chevron\"],\"description\":\"shape identifier\"},\"outside_edge_length\":{\"m"
    "inimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"lengt"
    "h of the two outer edges in meters\"},\"thickness\":{\"minimum\":0,\"type\":\""
    "number\",\"exclusiveMinimum\":true,\"description\":\"thickness in "
    "meters\"}},\"description\":\"chevron specific properties\"}],\"description\":"
    "\"chevron\"},\"checkerboard2x2\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/defi"
    "nitions/common\"},{\"type\":\"object\",\"required\":[\"shape\",\"square_length\"]"
    ",\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"checkerboard2x2\"],\"de"
    "scription\":\"shape identifier\"},\"square_length\":{\"minimum\":0,\"type\":\"nu"
    "mber\",\"exclusiveMinimum\":true,\"description\":\"length of a square of the"
    " checkerboard in meters\"}},\"description\":\"checkerboard specific "
    "properties\"}],\"description\":\"checkerboard 2 by 2\"},\"round_corner_cube_"
    "prism\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"typ"
    "e\":\"object\",\"required\":[\"shape\",\"diameter\"],\"properties\":{\"shape\":{\"ty"
    "pe\":\"string\",\"enum\":[\"round_corner_cube_prism\"],\"description\":\"shape "
    "identifier\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"},\"diameter\":{\"minimum\":0,\""
    "type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"diameter in "
    "meters\"}},\"description\":\"round corner cube prism specific "
    "properties\"}],\"description\":\"round corner cube "
    "prism\"}},\"description\":\"List of control object type definitions\"}"
    ,
    /* example: */
    "{\"types\":[{\"width\":0.3,\"shape\":\"rectangle\",\"length\":0.6,\"description\":"
    "\"Rectangle (60cm x 30cm)\",\"name\":\"Rectangle 60x30\"},{\"width\":0.4,\"shap"
    "e\":\"rectangle\",\"length\":0.8,\"description\":\"Rectangle (80cm x "
    "40cm)\",\"name\":\"Rectangle "
    "80x40\"},{\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square"
    " length: 30cm)\",\"square_length\":0.3,\"name\":\"Checkerboard2x2 "
    "30\"},{\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square "
    "length: 50cm)\",\"square_length\":0.5,\"name\":\"Checkerboard2x2 "
    "50\"},{\"shape\":\"chevron\",\"description\":\"Chevron (a=24''; b=4'')\",\"outsi"
    "de_edge_length\":0.6096,\"thickness\":0.1016,\"name\":\"Chevron 24''/4''\"},{"
    "\"surface_type\":\"diffuse\",\"shape\":\"circular_disk\",\"description\":\" "
    "Circular Disk (diameter: 50cm)\",\"diameter\":0.5,\"name\":\"Circular Disk "
    "50\"},{\"shape\":\"circular_disk\",\"name\":\"RIEGL flat reflector 50 mm\",\"dia"
    "meter\":0.05,\"offset\":0.0,\"surface_type\":\"retro_reflective_foil\",\"descr"
    "iption\":\"flat circular reflector from retro-reflective "
    "foil\"},{\"shape\":\"circular_disk\",\"name\":\"RIEGL flat reflector 100 mm\",\""
    "diameter\":0.1,\"offset\":0.0,\"surface_type\":\"retro_reflective_foil\",\"des"
    "cription\":\"flat circular reflector from retro-reflective "
    "foil\"},{\"shape\":\"circular_disk\",\"name\":\"RIEGL flat reflector 150 mm\",\""
    "diameter\":0.15,\"offset\":0.0,\"surface_type\":\"retro_reflective_foil\",\"de"
    "scription\":\"flat circular reflector from retro-reflective "
    "foil\"},{\"shape\":\"cylinder\",\"height\":0.05,\"name\":\"RIEGL cylindrical "
    "reflector 50 mm\",\"diameter\":0.05,\"surface_type\":\"retro_reflective_foil"
    "\",\"description\":\"cylindrical reflector from retro-reflective "
    "foil\"},{\"shape\":\"cylinder\",\"height\":0.1,\"name\":\"RIEGL cylindrical "
    "reflector 100 mm\",\"diameter\":0.1,\"surface_type\":\"retro_reflective_foil"
    "\",\"description\":\"cylindrical reflector from retro-reflective "
    "foil\"},{\"shape\":\"sphere\",\"description\":\"Sphere (diameter: 200 "
    "mm)\",\"diameter\":0.2,\"name\":\"Sphere 200 mm\"},{\"shape\":\"round_corner_cub"
    "e_prism\",\"offset\":0.0,\"description\":\"round corner cube "
    "prism\",\"diameter\":0.05,\"name\":\"Corner Cube Prism 50 "
    "mm\"}],\"comments\":[\"This file contains a list of control object types "
    "(aka. 'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Control "
    "Object Reference file\",\"type\":\"object\",\"properties\":{\"reference_file\":"
    "{\"type\":\"object\",\"required\":[\"file_uuid\",\"file_path\"],\"properties\":{\"f"
    "ile_uuid\":{\"type\":\"string\",\"description\":\"Control object file's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "control object file relative to referring "
    "file\"}},\"description\":\"Reference to a control object "
    "file\"}},\"description\":\"Details about the control object reference "
    "file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\","
    "\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoints.cpx\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"detection_probability\"],\"title\":\"Detection P"
    "robability\",\"properties\":{\"amplitude\":{\"items\":{\"type\":\"number\"},\"type"
    "\":\"array\",\"description\":\"Amplitude [dB]\"},\"detection_probability\":{\"it"
    "ems\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Detection "
    "probability [0..1]\"}},\"$schema\":\"http://json-schema.org/draft-04/schem"
    "a#\",\"type\":\"object\",\"description\":\"Detection probability as a function"
    " of amplitude\"}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"detection"
    "_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"device_type\",\"serial_number\"],\"title\":\"Device Informatio"
    "n\",\"properties\":{\"device_name\":{\"type\":\"string\",\"description\":\"Optiona"
    "l device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel devices)\"}"
    ",\"channel_number\":{\"minimum\":0,\"type\":\"integer\",\"exclusiveMinimum\":fal"
    "se,\"description\":\"Laser channel number (not defined or 0: single "
    "channel device)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device"
    " type identifier (e.g. "
    "VZ-400i)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\""
    ":\"object\",\"description\":\"Details about the device used to acquire the "
    "point cloud\"}"
    ,
    /* example: */
    "{\"device_name\":\"Scanner 1\",\"serial_number\":\"S2221234\",\"channel_text\":\""
    "\",\"channel_number\":0,\"device_type\":\"VZ-400i\",\"device_build\":\"\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"primary\"],\"title\":\"Device Geometry\",\"properties\":{\"secon"
    "dary\":{\"type\":\"object\",\"required\":[\"ID\",\"content\"],\"properties\":{\"ID\":"
    "{\"maxItems\":2,\"items\":{\"type\":\"integer\"},\"type\":\"array\",\"minItems\":2,\""
    "description\":\"Structure identifier\"},\"content\":{\"items\":{\"type\":\"numbe"
    "r\"},\"type\":\"array\",\"description\":\"Internal calibration "
    "values\"}},\"description\":\"Additional device geometry structure (optiona"
    "l)\"},\"primary\":{\"type\":\"object\",\"required\":[\"ID\",\"content\"],\"propertie"
    "s\":{\"ID\":{\"maxItems\":2,\"items\":{\"type\":\"integer\"},\"type\":\"array\",\"minI"
    "tems\":2,\"description\":\"Structure identifier\"},\"content\":{\"items\":{\"typ"
    "e\":\"number\"},\"type\":\"array\",\"description\":\"Internal calibration "
    "values\"}},\"description\":\"Primary device geometry structure (mandatory)"
    "\"},\"amu\":{\"type\":\"object\",\"properties\":{\"frameCC\":{\"minimum\":0,\"type\":"
    "\"number\",\"exclusiveMinimum\":false,\"description\":\"Frame Circle Count "
    "(number of LSBs per full rotation about frame axis)\"},\"lineCC\":{\"minim"
    "um\":0,\"type\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Line "
    "Circle Count (number of LSBs per full rotation about line "
    "axis)\"}},\"description\":\"Angle Measurement Unit\"}},\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Scanner"
    " device geometry details\"}"
    ,
    /* example: */
    "{\"secondary\":{\"ID\":[91,0],\"content\":[0]},\"primary\":{\"ID\":[4,0],\"conten"
    "t\":[0]},\"amu\":{\"frameCC\":124000,\"lineCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"primary\"],\"title\":\"Device Geometry Passive Channel\",\"pro"
    "perties\":{\"primary\":{\"type\":\"object\",\"required\":[\"ID\",\"content\"],\"prop"
    "erties\":{\"ID\":{\"maxItems\":2,\"items\":{\"type\":\"integer\"},\"type\":\"array\","
    "\"minItems\":2,\"description\":\"Structure identifier\"},\"content\":{\"items\":"
    "{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Internal calibration "
    "values\"}},\"description\":\"Primary device geometry structure (mandatory)"
    "\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object"
    "\",\"description\":\"Scanner passive channel device geometry details\"}"
    ,
    /* example: */
    "{\"primary\":{\"ID\":[143,0],\"content\":[0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Device "
    "Output Limits\",\"type\":\"object\",\"properties\":{\"background_radiation_min"
    "imum\":{\"type\":\"number\",\"description\":\"Minimum possible background radi"
    "ation.\"},\"mta_zone_count_maximum\":{\"type\":\"number\",\"description\":\"Maxi"
    "mum number of MTA "
    "zones.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"},\"amplitude_maximum\":{\"type\":\"number\""
    ",\"description\":\"Maximum possible amplitude in "
    "dB.\"},\"reflectance_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible reflectance in "
    "dB.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "number of echoes a laser shot can "
    "have.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible range in meters.\"},\"reflectance_maximum\":{\"type\":\"number\",\"de"
    "scription\":\"Maximum possible reflectance in dB.\"},\"background_radiatio"
    "n_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible background"
    " radiation.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible range in "
    "meters.\"},\"amplitude_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape deviation.\"}},\"description\":\"Limits of the "
    "measured values output by the device. The limits depend on the device "
    "type, measurement program and/or scan pattern.\"}"
    ,
    /* example: */
    "{\"background_radiation_minimum\":0,\"background_radiation_maximum\":0,\"mt"
    "a_zone_count_maximum\":7,\"range_minimum\":2.9,\"amplitude_minimum\":0.0,\"r"
    "eflectance_maximum\":100.0,\"reflectance_minimum\":-100.0,\"deviation_mini"
    "mum\":-1,\"range_maximum\":10000.0,\"amplitude_maximum\":100.0,\"deviation_m"
    "aximum\":32767}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"items\":{\"type\":\"object\",\"required\":[\"device_type\",\"serial_number\"],\""
    "properties\":{\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set "
    "when the original 'riegl.device' entry in the source file was "
    "correctly signed.\"},\"channel_number\":{\"minimum\":0,\"type\":\"integer\",\"ex"
    "clusiveMinimum\":false,\"description\":\"Laser channel number (not defined"
    " or 0: single channel "
    "device)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"titl"
    "e\":\"Devices Information\",\"type\":\"array\",\"description\":\"Details about "
    "the devices used to acquire the point cloud (e.g. when merging point "
    "clouds of different devices)\"}"
    ,
    /* example: */
    "[{\"device_name\":\"Scanner 1\",\"serial_number\":\"S2221234\",\"channel_text\":"
    "\"\",\"signed\":false,\"channel_number\":0,\"device_type\":\"VZ-400i\",\"device_b"
    "uild\":\"\"},{\"device_name\":\"Scanner 2\",\"serial_number\":\"S2222680\",\"chann"
    "el_text\":\"\",\"signed\":true,\"channel_number\":1,\"device_type\":\"VQ-1560i-D"
    "W\",\"device_build\":\"\"},{\"device_name\":\"Scanner 3\",\"serial_number\":\"S222"
    "2680\",\"channel_text\":\"\",\"signed\":true,\"channel_number\":2,\"device_type\""
    ":\"VQ-1560i-DW\",\"device_build\":\"\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Dyntrig\""
    ",\"properties\":{\"pre\":{\"type\":\"object\",\"required\":[\"nc\",\"a\"],\"propertie"
    "s\":{\"nc\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"Number of entrie"
    "s\",\"maximum\":255},\"a\":{\"maxItems\":2080,\"items\":{\"type\":\"number\"},\"type"
    "\":\"array\",\"minItems\":1,\"description\":\"...\"}},\"description\":\"Dyntrig "
    "pre values\"},\"offset\":{\"type\":\"number\",\"description\":\"Offset in units "
    "of dB, for calculation of "
    "line\"},\"scale\":{\"type\":\"number\",\"description\":\"Scale in units of dB, "
    "for calculation of line: line number N=(amplitude-offset)/scale\"},\"tab"
    "\":{\"maxItems\":128,\"items\":{\"type\":\"object\",\"required\":[\"thra1\",\"del1\","
    "\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"properties\":{\"thra2\":{\"type\":\"number\",\""
    "description\":\"Pre-trigger threshold in units of "
    "dB\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of "
    "m\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of pre-trigger "
    "threshold after del2 in units of "
    "dB/m\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold "
    "in units of dB\"}},\"description\":\"...\"},\"type\":\"array\",\"minItems\":1,\"de"
    "scription\":\"...\"},\"post\":{\"type\":\"object\",\"required\":[\"nc\",\"a\"],\"prope"
    "rties\":{\"nc\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"Number of en"
    "tries\",\"maximum\":255},\"a\":{\"maxItems\":2080,\"items\":{\"type\":\"number\"},\""
    "type\":\"array\",\"minItems\":1,\"description\":\"...\"}},\"description\":\"Dyntri"
    "g post values\"}},\"description\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"pre\":{\"nc\":128,\"a\":[78,86,126,134,31]},\"offset\":0.0,\"scale\":1.0,\"tab"
    "\":[{\"thra2\":0.0,\"del1\":0.0,\"del2\":0.0,\"dec2\":0.0,\"dec1\":0.0,\"thra1\":0."
    "0}],\"post\":{\"nc\":128,\"a\":[78,86,126,134,31]}}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"echo_file\"],\"title\":\"Echo Information\",\"properties\":{\"ec"
    "ho_file\":{\"type\":\"object\",\"required\":[\"file_extension\"],\"properties\":{"
    "\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading dot\"}}}},\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Details about "
    "echo files\"}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/channel\",\"desc"
    "ription\":\"one field per channel, field name is channel "
    "index\"}},\"title\":\"Exponential Decomposition\",\"additionalProperties\":fa"
    "lse,\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object"
    "\",\"definitions\":{\"channel\":{\"type\":\"object\",\"required\":[\"delay\",\"scale"
    "\",\"parameter\"],\"properties\":{\"a_lin\":{\"exclusiveMaximum\":false,\"exclus"
    "iveMinimum\":false,\"maximum\":1,\"minimum\":0,\"type\":\"number\",\"description"
    "\":\"relative linear amplitude range [0..1]\"},\"parameter\":{\"type\":\"objec"
    "t\",\"required\":[\"A\",\"B\",\"gamma\",\"omega\"],\"properties\":{\"A\":{\"items\":{\"t"
    "ype\":\"number\"},\"type\":\"array\",\"description\":\"real part of amplitude "
    "factor in units of full-scale\"},\"omega\":{\"items\":{\"type\":\"number\"},\"ty"
    "pe\":\"array\",\"description\":\"angular frequency in Hz\"},\"B\":{\"items\":{\"ty"
    "pe\":\"number\"},\"type\":\"array\",\"description\":\"imaginary part of "
    "amplitude factor in units of full-scale\"},\"gamma\":{\"items\":{\"type\":\"nu"
    "mber\"},\"type\":\"array\",\"description\":\"decay in "
    "1/second\"}},\"description\":\"parameters of the syswave exponential "
    "sum\"},\"delay\":{\"type\":\"number\",\"description\":\"delay calibration in "
    "seconds\"},\"scale\":{\"type\":\"number\",\"description\":\"amplitude "
    "calibration\"}}}},\"description\":\"Details for exponential decomposition "
    "of full waveform data\"}"
    ,
    /* example: */
    "{\"1\":{\"a_lin\":0.9,\"parameter\":{\"A\":[0.9,0.3,-1.3],\"omega\":[352020896.0"
    ",3647927552.0,-1977987072.0],\"B\":[-3.9,0.0,-0.3],\"gamma\":[-1094726528."
    "0,-769562752.0,-848000064.0]},\"delay\":3.5e-09,\"scale\":1.0},\"0\":{\"a_lin"
    "\":0.27,\"parameter\":{\"A\":[0.9772450923919678,0.3354335129261017,-1.3126"
    "78575515747],\"omega\":[352020896.0,3647927552.0,-1977987072.0],\"B\":[-3."
    "9813032150268555,0.08622030913829803,-0.3152860999107361],\"gamma\":[-10"
    "94726528.0,-769562752.0,-848000064.0]},\"delay\":3.783458418887631e-09,\""
    "scale\":1.0}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amp"
    "litude_db\",\"range_offset_sec_low_power\",\"range_offset_sec_high_power\"]"
    ",\"title\":\"Gaussian Decomposition\",\"properties\":{\"amplitude_lsb_high_po"
    "wer\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_lsb_low_pow"
    "er\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"range_offset_sec_high_"
    "power\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"range_offset_sec_lo"
    "w_power\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_db\":{\"i"
    "tems\":{\"type\":\"number\"},\"type\":\"array\"}},\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"type\":\"object\",\"description\":\"riegl.gaussian_d"
    "ecomposition contains information relevant for extracting calibrated "
    "amplitudes and calibrated ranges from a Gaussian decomposition of full"
    " waveform data. This information is contained in a table with five "
    "columns. Two columns are to be used as input: amplitude_lsb_low_power "
    "and amplitude_lsb_high_power. The other three columns provide the "
    "outputs. Amplitude_db gives the calibrated amplitude in the optical "
    "regime in decibels. The range offset columns provide additive range "
    "offsets, given in units of seconds, for each channel.\"}"
    ,
    /* example: */
    "{\"amplitude_lsb_high_power\":[],\"amplitude_lsb_low_power\":[],\"range_off"
    "set_sec_high_power\":[],\"range_offset_sec_low_power\":[],\"amplitude_db\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Geo Tag\""
    ",\"type\":\"object\",\"properties\":{\"crs\":{\"type\":\"object\",\"properties\":{\"e"
    "psg\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"EPSG "
    "code\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"},\"name\":{\"type\":\"string\",\"description\":\"Coordinate reference "
    "system name\"}},\"description\":\"Global Coordinate Reference System. "
    "Please note that only 3D Cartesian Coordinate Systems are allowed.\"},\""
    "pose\":{\"maxItems\":4,\"items\":{\"maxItems\":4,\"items\":{\"type\":\"number\",\"de"
    "scription\":\"columns\"},\"type\":\"array\",\"minItems\":4,\"description\":\"rows\""
    "},\"type\":\"array\",\"minItems\":4,\"description\":\"Coordinate Transformation"
    " Matrix to transform from File Coordinate System to Global Coordinate "
    "Reference System. 4x4 matrix stored as two dimensional array, row "
    "major order.\"}},\"description\":\"Point cloud georeferencing "
    "information\"}"
    ,
    /* example: */
    "{\"crs\":{\"epsg\":4978,\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\""
    ",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"703"
    "0\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.00000000000"
    "00000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000"
    "000,AUTHORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],A"
    "XIS[\\\"Z\\\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"name\":\"WGS84 Geocentr"
    "ic\"},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"minimum\":0,\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type"
    "\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Geometric scale "
    "factor applied to point coordinates\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Georefer"
    "encing Parameters\",\"type\":\"object\",\"properties\":{\"trajectory_file\":{\"t"
    "ype\":\"object\",\"required\":[\"file_extension\"],\"properties\":{\"file_uuid\":"
    "{\"type\":\"string\",\"description\":\"File's Universally Unique Identifier "
    "(RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading dot\"}},\"description\":\"Trajectory "
    "data used for georeferencing of the point cloud\"},\"socs_to_body_matrix"
    "\":{\"maxItems\":4,\"items\":{\"maxItems\":4,\"items\":{\"type\":\"number\",\"descri"
    "ption\":\"columns\"},\"type\":\"array\",\"minItems\":4,\"description\":\"rows\"},\"t"
    "ype\":\"array\",\"minItems\":4,\"description\":\"Coordinate Transformation "
    "Matrix to transform from Scanner's Own Coordinate System to Body "
    "Coordinate System. 4x4 matrix stored as two dimensional array, row "
    "major order.\"},\"trajectory_offsets\":{\"type\":\"object\",\"properties\":{\"of"
    "fset_yaw\":{\"type\":\"number\",\"description\":\"[deg]\"},\"offset_pitch\":{\"typ"
    "e\":\"number\",\"description\":\"[deg]\"},\"offset_roll\":{\"type\":\"number\",\"des"
    "cription\":\"[deg]\"},\"offset_north\":{\"type\":\"number\",\"description\":\"[m]\""
    "},\"offset_height\":{\"type\":\"number\",\"description\":\"[m]\"},\"version\":{\"ty"
    "pe\":\"integer\",\"description\":\"Meaning of offset values and how to apply"
    " them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_east\":{\"type\":\"number\",\"description\":\"[m]\""
    "},\"offset_time\":{\"type\":\"number\",\"description\":\"[s]\"}},\"description\":\""
    "Correction offsets applied to the trajectory data\"},\"body_coordinate_s"
    "ystem_type\":{\"type\":\"string\",\"enum\":[\"NED\",\"ENU\"],\"description\":\"BODY "
    "coordinate frame (NED: North-East-Down, ENU: East-North-Up), default: "
    "NED\"},\"socs_to_rocs_matrix\":{\"maxItems\":4,\"items\":{\"maxItems\":4,\"items"
    "\":{\"type\":\"number\",\"description\":\"columns\"},\"type\":\"array\",\"minItems\":"
    "4,\"description\":\"rows\"},\"type\":\"array\",\"minItems\":4,\"description\":\"Coo"
    "rdinate Transformation Matrix to transform from Scanner's Own "
    "Coordinate System to Record Coordinate System. 4x4 matrix stored as "
    "two dimensional array, row major order.\"}},\"description\":\"Parameters "
    "used for georeferencing of the point cloud\"}"
    ,
    /* example: */
    "{\"trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\""
    ",\"file_extension\":\"pofx\"},\"socs_to_body_matrix\":[[-0.269827776749716,-"
    "0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051"
    "7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,"
    "0.0],[0.0,0.0,0.0,1.0]],\"trajectory_offsets\":{\"offset_yaw\":-0.45,\"offs"
    "et_pitch\":0.01,\"offset_roll\":0.03,\"offset_north\":0.07,\"offset_height\":"
    "-0.2,\"version\":0,\"offset_east\":0.15,\"offset_time\":18.007},\"body_coordi"
    "nate_system_type\":\"NED\"}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Item Names\",\"additionalProperties\":false,\"pa"
    "tternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"description\":\"One "
    "field per item, field name is item id, field value is item name\"}},\"$s"
    "chema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Map of"
    " item names\"}"
    ,
    /* example: */
    "{\"2\":\"Name of item with id 2\",\"47\":\"Name of item with id 47\",\"1\":\"Name"
    " of item with id 1\",\"-1\":\"Name of item with id -1\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Software License Keys\",\"additionalProperties"
    "\":false,\"patternProperties\":{\"^.*$\":{\"items\":{\"type\":\"string\",\"descrip"
    "tion\":\"License key (example: '46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"},\"type\":\"array\",\"minItems\":1,\"description\":\"Each field of "
    "the object represents a feature and holds a list of license keys, "
    "where the field name is the feature name.\"}},\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"description\":\"License keys for software "
    "features\"}"
    ,
    /* example: */
    "{\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - 6F163D73\"],\"Full "
    "Waveform Analysis Topography with GPU support\":[\"8AB44126 - 23B92250 -"
    " 16E2689F - 34EF7E7B\"],\"MTA resolution\":[\"468E020A - 39A922E4 - "
    "B681A184 - 673E3D72\"],\"Full Waveform Analysis Topography\":[\"0FD5FF07 -"
    " 011A1255 - 9F76CACA - 8D2ED557\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"MTA Sett"
    "ings\",\"type\":\"object\",\"properties\":{\"zone_count\":{\"minimum\":0,\"type\":\""
    "integer\",\"maximum\":255,\"description\":\"Maximum number of MTA zones.\"},\""
    "zone_width\":{\"minimum\":0,\"type\":\"number\",\"description\":\"Width of a MTA"
    " zone in meter.\"},\"modulation_depth\":{\"minimum\":0,\"type\":\"number\",\"des"
    "cription\":\"Depth of pulse position modulation in "
    "meter.\"}},\"description\":\"Parameters for MTA processing\"}"
    ,
    /* example: */
    "{\"zone_count\":23,\"zone_width\":149.896225,\"modulation_depth\":9.368514}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"delta\",\"content\"],\"title\":\"Near Range Correction "
    "Table\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\"},\"content\":{"
    "\"maxItems\":2000,\"items\":{\"type\":\"number\"},\"type\":\"array\",\"minItems\":1,"
    "\"description\":\"Correction value [m] to be added to the raw range\"}},\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"des"
    "cription\":\"Lookup table for range correction based on raw range\"}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"],\"title\":\"Noi"
    "se Estimates\",\"properties\":{\"amplitude\":{\"items\":{\"type\":\"number\"},\"ty"
    "pe\":\"array\",\"description\":\"Amplitude [dB]\"},\"amplitude_sigma\":{\"items\""
    ":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Sigma amplitude [dB]\""
    "},\"range_sigma\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description"
    "\":\"Sigma range [m]\"}},\"$schema\":\"http://json-schema.org/draft-04/schem"
    "a#\",\"type\":\"object\",\"description\":\"Standard deviation for range and "
    "amplitude as a function of amplitude\"}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"amplitude"
    "_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.432,0.39,0.3"
    "54],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.0"
    "18,0.016,0.014]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_maximum\"],\"tit"
    "le\":\"Notch Filter\",\"properties\":{\"range_minimum\":{\"type\":\"number\",\"des"
    "cription\":\"Minimum range [m]\"},\"amplitude_maximum\":{\"minimum\":0,\"type\""
    ":\"number\",\"description\":\"Maximum amplitude "
    "[dB]\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum range ["
    "m]\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obje"
    "ct\",\"description\":\"Notch filter parameters for window glass echoes\"}"
    ,
    /* example: */
    "{\"range_minimum\":-0.5,\"amplitude_maximum\":18.0,\"range_maximum\":0.2}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"size\"],\"title\":\"Pixel Information\",\"properties\":{\"size_l"
    "lcs\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Size of pixels "
    "in a locally levelled cartesian coordinate system (xy). This is only "
    "used for pixels based on a map projection.\"},\"size\":{\"$ref\":\"#/definit"
    "ions/pixel_size\",\"description\":\"Size of pixels in file coordinate syst"
    "em.\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obj"
    "ect\",\"definitions\":{\"pixel_size\":{\"maxItems\":2,\"items\":{\"minimum\":0,\"t"
    "ype\":\"number\",\"description\":\"Length of pixel edge "
    "[m].\"},\"type\":\"array\",\"minItems\":2,\"description\":\"Size of "
    "pixels.\"}},\"description\":\"Details about the pixels contained in the "
    "file\"}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"],\"title\":\"P"
    "lane Patch Matching\",\"properties\":{\"plane_patch_file_two\":{\"$ref\":\"#/d"
    "efinitions/file_reference\",\"description\":\"Reference to the plane patch"
    " file two\"},\"plane_patch_file_one\":{\"$ref\":\"#/definitions/file_referen"
    "ce\",\"description\":\"Reference to the plane patch file one\"}},\"$schema\":"
    "\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"definitions"
    "\":{\"file_reference\":{\"type\":\"object\",\"required\":[\"file_uuid\",\"file_pat"
    "h\"],\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane "
    "patch file's Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the plane "
    "patch file relative to the match file\"}},\"description\":\"Reference to a"
    " plane patch file\"}},\"description\":\"Details about the plane patch "
    "matching process\"}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_uuid\":\"fa47d509-a64e-49ce-8b14-ff3130fb"
    "efa9\",\"file_path\":\"project.ptch\"},\"plane_patch_file_one\":{\"file_uuid\":"
    "\"810f5d57-eccf-49ed-b07a-0cdd109b4213\",\"file_path\":\"Record009_Line001/"
    "191025_121410_Scanner_1.ptch\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Plane "
    "Patch Statistics\",\"type\":\"object\",\"properties\":{\"total_horizontal_area"
    "\":{\"type\":\"number\",\"description\":\"sum of all plane patch areas "
    "projected to horizontal plane "
    "[m\\u00b2]\"},\"total_area\":{\"type\":\"number\",\"description\":\"sum of all "
    "plane patch areas [m\\u00b2]\"}},\"description\":\"Statistics about plane "
    "patches found by plane patch extractor\"}"
    ,
    /* example: */
    "{\"total_horizontal_area\":13954.601,\"total_area\":14007.965}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"settings\",\"classes\"],\"title\":\"Plane Slope Class Info\",\"p"
    "roperties\":{\"settings\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definition"
    "s/method-1\"},{\"$ref\":\"#/definitions/method-2\"}],\"description\":\"Classif"
    "ication settings, details see documentation of rdbplanes\"},\"classes\":{"
    "\"type\":\"object\",\"additionalProperties\":false,\"patternProperties\":{\"^[0"
    "-9]+$\":{\"type\":\"string\",\"description\":\"one field per class, field name"
    " is class number, field value is class name\"}},\"description\":\"Class "
    "definition table\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#"
    "\",\"type\":\"object\",\"definitions\":{\"method-1\":{\"type\":\"object\",\"required"
    "\":[\"plane_classification_method\",\"maximum_inclination_angle_horizontal"
    "\"],\"properties\":{\"maximum_inclination_angle_horizontal\":{\"minimum\":-36"
    "0.0,\"type\":\"number\",\"maximum\":360.0,\"description\":\"maximum inclination"
    " angle of horizontal plane patches [deg]\"},\"plane_classification_metho"
    "d\":{\"minimum\":1,\"type\":\"integer\",\"maximum\":1,\"description\":\"method ID "
    "(=1)\"}},\"description\":\"Classification method 1\"},\"method-2\":{\"type\":\"o"
    "bject\",\"required\":[\"plane_classification_method\",\"sloping_plane_classe"
    "s_minimum_angle\",\"sloping_plane_classes_maximum_angle\"],\"properties\":{"
    "\"sloping_plane_classes_minimum_angle\":{\"minimum\":-360.0,\"type\":\"number"
    "\",\"maximum\":360.0,\"description\":\"minimum inclination angle of sloping "
    "plane patches [deg]\"},\"sloping_plane_classes_maximum_angle\":{\"minimum\""
    ":-360.0,\"type\":\"number\",\"maximum\":360.0,\"description\":\"maximum "
    "inclination angle of sloping plane patches [deg]\"},\"plane_classificati"
    "on_method\":{\"minimum\":2,\"type\":\"integer\",\"maximum\":2,\"description\":\"me"
    "thod ID (=2)\"}},\"description\":\"Classification method "
    "2\"}},\"description\":\"Settings and classes for plane slope "
    "classification\"}"
    ,
    /* example: */
    "{\"settings\":{\"sloping_plane_classes_minimum_angle\":10.0,\"sloping_plane"
    "_classes_maximum_angle\":70.0,\"plane_classification_method\":2},\"classes"
    "\":{\"11\":\"sloping, pointing down and south\",\"10\":\"sloping, pointing "
    "down and east\",\"5\":\"sloping, pointing up and west\",\"3\":\"sloping, "
    "pointing up and south\",\"4\":\"sloping, pointing up and "
    "north\",\"12\":\"sloping, pointing down and north\",\"1\":\"horizontal, "
    "pointing up\",\"14\":\"horizontal, pointing down\",\"2\":\"sloping, pointing "
    "up and east\",\"9\":\"vertical, pointing west\",\"13\":\"sloping, pointing "
    "down and west\",\"8\":\"vertical, pointing north\",\"6\":\"vertical, pointing "
    "east\",\"7\":\"vertical, pointing south\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Point Attribute Groups\",\"additionalPropertie"
    "s\":false,\"patternProperties\":{\"^.*$\":{\"items\":{\"type\":\"string\",\"descri"
    "ption\":\"Point attribute full name or name pattern (perl regular "
    "expression syntax)\"},\"type\":\"array\",\"minItems\":1,\"description\":\"Each "
    "field of the object represents a point attribute group and holds a "
    "list of point attributes, where the field name is the group name.\"}},\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Grou"
    "ping and sorting of point attributes for visualization purposes\"}"
    ,
    /* example: */
    "{\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl"
    ".phi\"],\"Secondary Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_av"
    "ailable\"],\"Time\":[\"riegl.timestamp\"],\"Primary Attributes\":[\"riegl.refl"
    "ectance\",\"riegl.amplitude\",\"riegl.deviation\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Point "
    "Cloud Information\",\"type\":\"object\",\"properties\":{\"field_of_application"
    "\":{\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"AL"
    "S\",\"BLS\",\"ILS\"],\"description\":\"Field of application\"},\"comments\":{\"typ"
    "e\":\"string\",\"description\":\"Comments\"},\"project\":{\"type\":\"string\",\"desc"
    "ription\":\"Project name\"}},\"description\":\"Details about point cloud "
    "files\"}"
    ,
    /* example: */
    "{\"field_of_application\":\"ALS\",\"comments\":\"Line 3\",\"project\":\"Campaign "
    "4\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"orientation\"],\"title\":\"Pose Estimation\",\"properties\":{\"p"
    "osition\":{\"type\":\"object\",\"required\":[\"coordinate_1\",\"coordinate_2\",\"c"
    "oordinate_3\",\"horizontal_accuracy\",\"vertical_accuracy\",\"crs\"],\"propert"
    "ies\":{\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordinate 1 as "
    "defined by axis 1 of the specified CRS (e.g., X, Latitude)\"},\"crs\":{\"t"
    "ype\":\"object\",\"required\":[\"epsg\"],\"properties\":{\"wkt\":{\"type\":\"string\""
    ",\"description\":\"\\\"Well-Known Text\\\" string, OGC WKT dialect (see http:"
    "//www.opengeospatial.org/standards/wkt-crs)\"},\"epsg\":{\"minimum\":0,\"typ"
    "e\":\"integer\",\"description\":\"EPSG code\"}},\"description\":\"Global "
    "Coordinate Reference "
    "System\"},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate 3 "
    "as defined by axis 3 of the specified CRS (e.g., Z, "
    "Altitude)\"},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coordinate "
    "2 as defined by axis 2 of the specified CRS (e.g., Y, Longitude)\"},\"ho"
    "rizontal_accuracy\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":tru"
    "e,\"description\":\"Horizontal accuracy [m]\"},\"vertical_accuracy\":{\"minim"
    "um\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Vertical "
    "accuracy [m]\"}},\"description\":\"Position coordinates and position "
    "accuracy values as measured by GNSS in the specified Coordinate "
    "Reference System (CRS)\"},\"barometric_height_amsl\":{\"type\":\"number\",\"de"
    "scription\":\"Altitude determined based on the atmospheric pressure "
    "according to the standard atmosphere laws [m].\"},\"orientation\":{\"type\""
    ":\"object\",\"required\":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accu"
    "racy\",\"yaw_accuracy\"],\"properties\":{\"pitch_accuracy\":{\"minimum\":0,\"typ"
    "e\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Pitch angle "
    "accuracy [deg]\"},\"roll\":{\"minimum\":-360,\"type\":\"number\",\"maximum\":360,"
    "\"description\":\"Roll angle about scanner X-axis [deg]\"},\"yaw\":{\"minimum"
    "\":-360,\"type\":\"number\",\"maximum\":360,\"description\":\"Yaw angle about "
    "scanner Z-axis [deg]\"},\"yaw_accuracy\":{\"minimum\":0,\"type\":\"number\",\"ex"
    "clusiveMinimum\":true,\"description\":\"Yaw angle accuracy [deg]\"},\"pitch\""
    ":{\"minimum\":-360,\"type\":\"number\",\"maximum\":360,\"description\":\"Pitch "
    "angle about scanner Y-axis [deg]\"},\"roll_accuracy\":{\"minimum\":0,\"type\""
    ":\"number\",\"exclusiveMinimum\":true,\"description\":\"Roll angle accuracy "
    "[deg]\"}},\"description\":\"Orientation values and orientation accuracies,"
    " measured with IMU or inclination sensors.\"}},\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Estimated "
    "position and orientation information as measured by GNSS, IMU or "
    "inclination sensors\"}"
    ,
    /* example: */
    "{\"position\":{\"coordinate_1\":48.655799473,\"crs\":{\"wkt\":\"GEOGCS[\\\"WGS84 "
    "/ Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.2572"
    "23563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIM"
    "EM[\\\"Greenwich\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT"
    "[\\\"Degree\\\",0.01745329251994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS["
    "\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979"
    "\\\"]]\",\"epsg\":4979},\"coordinate_3\":362.7124938964844,\"coordinate_2\":15."
    "645033406,\"horizontal_accuracy\":0.810699999332428,\"vertical_accuracy\":"
    "1.3314999341964722},\"barometric_height_amsl\":386.7457796227932,\"orient"
    "ation\":{\"pitch_accuracy\":0.009433783936875745,\"roll\":3.14743073066123,"
    "\"yaw\":101.87293630292045,\"yaw_accuracy\":1.0094337839368757,\"pitch\":1.5"
    "09153024827064,\"roll_accuracy\":0.009433783936875745}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"gyroscope\",\"accelerometer\",\"magnetic_field_sensor\"],\"tit"
    "le\":\"Pose Sensors\",\"properties\":{\"magnetic_field_sensor\":{\"type\":\"obje"
    "ct\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"re"
    "lative_nonlinearity\"],\"properties\":{\"z_axis\":{\"$ref\":\"#/definitions/ve"
    "ctor\",\"description\":\"Sensitive Z axis of sensor at frame angle = 0\"},\""
    "unit\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descriptio"
    "n\":\"Unit of raw data and calibration values, 1 LSB in nT\"},\"relative_n"
    "onlinearity\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative "
    "nonlinearity, dimensionless\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\","
    "\"description\":\"Sensitive Y axis of sensor at frame angle = "
    "0\"},\"fixed\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Distortion "
    "of magnetic field caused by non-rotating scanner part\"},\"x_axis\":{\"$re"
    "f\":\"#/definitions/vector\",\"description\":\"Sensitive X axis of sensor at"
    " frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"}},\"description\":\"Magnetic "
    "Field Sensor details\"},\"accelerometer\":{\"type\":\"object\",\"required\":[\"u"
    "nit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlineari"
    "ty\"],\"properties\":{\"origin\":{\"$ref\":\"#/definitions/vector\",\"descriptio"
    "n\":\"Sensor origin in SOCS [m] at frame angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = 0\"},\"unit\":{\"minimum\":0,\"type\":\"numbe"
    "r\",\"exclusiveMinimum\":true,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\"},\"relative_nonlinearity\":"
    "{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative nonlinearity, d"
    "imensionless\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\""
    "Sensitive Y axis of sensor at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement "
    "values\"}},\"description\":\"Accelerometer details\"},\"gyroscope\":{\"type\":\""
    "object\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin"
    "\",\"relative_nonlinearity\"],\"properties\":{\"origin\":{\"$ref\":\"#/definitio"
    "ns/vector\",\"description\":\"Sensor origin in SOCS [m] at frame angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = 0\"},\"unit\":{\"minimum\":0,\"type\":\"numbe"
    "r\",\"exclusiveMinimum\":true,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in rad/s\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Y axis of sensor at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"}},\"description\":\"Gyroscope de"
    "tails\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"o"
    "bject\",\"definitions\":{\"vector\":{\"maxItems\":3,\"items\":{\"type\":\"number\","
    "\"description\":\"Index 0=X, 1=Y, 2=Z "
    "component\"},\"type\":\"array\",\"minItems\":3}},\"description\":\"Details on "
    "position and orientation sensors\"}"
    ,
    /* example: */
    "{\"magnetic_field_sensor\":{\"z_axis\":[0.00041987866279669106,7.876977906"
    "562388e-05,0.011407104320824146],\"unit\":91.74311828613281,\"relative_no"
    "nlinearity\":[0.0,0.0,0.0],\"y_axis\":[0.00027888521435670555,-0.01142742"
    "4848079681,-5.204829722060822e-05],\"fixed\":[-1576.010498046875,1596.08"
    "1787109375,0.0],\"x_axis\":[-0.011162743903696537,-2.315962774446234e-05"
    ",0.00016818844596855342],\"offset\":[-23812.052734375,5606.57666015625,2"
    "493.28125]},\"accelerometer\":{\"origin\":[0.026900000870227814,-0.0399999"
    "9910593033,-0.08950000256299973],\"z_axis\":[1.639882206916809,15166.744"
    "140625,-116.99742889404297],\"unit\":6.666666740784422e-05,\"relative_non"
    "linearity\":[0.0,0.0,0.0],\"y_axis\":[-7.027288913726807,-44.123336791992"
    "19,14952.3701171875],\"x_axis\":[-15008.123046875,56.956390380859375,-60"
    ".5175666809082],\"offset\":[-733.3636474609375,58.969032287597656,1060.2"
    "550048828125]},\"gyroscope\":{\"origin\":[0.026900000870227814,-0.03999999"
    "910593033,-0.08950000256299973],\"z_axis\":[0.555869996547699,119.221351"
    "62353516,0.467585027217865],\"unit\":0.00014544410805683583,\"relative_no"
    "nlinearity\":[2.888176311444113e-07,1.06274164579645e-07,-1.71862950806"
    "34935e-39],\"y_axis\":[-0.440765917301178,-0.7897399663925171,119.589477"
    "5390625],\"x_axis\":[-121.195556640625,0.8219714164733887,0.231303170323"
    "3719],\"offset\":[-50.92609786987305,146.15643310546875,62.4327278137207"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"],\"title\":\"Pulse "
    "Position Modulation\",\"properties\":{\"code_phase_mode\":{\"minimum\":0,\"typ"
    "e\":\"integer\",\"maximum\":255,\"description\":\"0: no synchronization, 1: "
    "toggle between 2 phases, 2: increment with phase_increment\"},\"length\":"
    "{\"minimum\":0,\"type\":\"integer\",\"maximum\":255,\"description\":\"Length of c"
    "ode\"},\"pulse_interval\":{\"items\":{\"minimum\":0,\"type\":\"number\"},\"type\":\""
    "array\",\"description\":\"Explicit table of the pulse position modulation "
    "used for MTA resolution. Table gives times between successive laser "
    "pulses in seconds.\"},\"phase_step\":{\"minimum\":0,\"type\":\"integer\",\"maxim"
    "um\":255,\"description\":\"Step width in phase of modulation code from "
    "line to line\"},\"num_mod_ampl\":{\"minimum\":0,\"type\":\"integer\",\"maximum\":"
    "255,\"description\":\"Number of different modulation amplitudes (2: "
    "binary modulation)\"}},\"$schema\":\"http://json-schema.org/draft-04/schem"
    "a#\",\"type\":\"object\",\"description\":\"Laser pulse position modulation "
    "used for MTA resolution\"}"
    ,
    /* example: */
    "{\"code_phase_mode\":2,\"length\":31,\"pulse_interval\":[2.759375e-06,2.7593"
    "75e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.759375e-0"
    "6,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.7"
    "59375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875"
    "e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,"
    "2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821"
    "875e-06,2.759375e-06,2.821875e-06],\"phase_step\":5,\"num_mod_ampl\":2}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"title\":\"Range S"
    "tatistics\",\"properties\":{\"minimum\":{\"type\":\"number\",\"description\":\"Min"
    "imum value\"},\"average\":{\"type\":\"number\",\"description\":\"Average "
    "value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum value\"}}"
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\""
    "description\":\"Statistics about target distance wrt. SOCS origin\"}"
    ,
    /* example: */
    "{\"minimum\":0.919,\"average\":15.49738,\"std_dev\":24.349,\"maximum\":574.35}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Receiver Internals\",\"properties\":{\"ex\":{\"type\":\"object\",\"des"
    "cription\":\"DEPRECATED, use 'riegl.exponential_decomposition' "
    "instead\"},\"ns\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"Number of "
    "samples\",\"maximum\":4095},\"tbl\":{\"items\":{\"$ref\":\"#/definitions/fp_tabl"
    "e\"},\"type\":\"array\",\"minItems\":1,\"description\":\"various internal data\"}"
    ",\"sr\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descriptio"
    "n\":\"Sample rate [Hz]\"},\"a\":{\"maxItems\":256,\"items\":{\"type\":\"number\"},\""
    "type\":\"array\",\"minItems\":1,\"description\":\"Amplitude "
    "[dB]\"},\"nt\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"Number of tra"
    "ces\",\"maximum\":255},\"si\":{\"minimum\":0,\"type\":\"number\",\"description\":\"S"
    "tart index (hw_start)\",\"maximum\":255},\"mw\":{\"minimum\":0,\"type\":\"number"
    "\",\"description\":\"Maximum weight\",\"exclusiveMinimum\":true,\"maximum\":409"
    "5},\"t\":{\"type\":\"object\",\"additionalProperties\":false,\"patternPropertie"
    "s\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/fp\",\"description\":\"one field per"
    " channel, field name is channel index\"}}}},\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"type\":\"object\",\"definitions\":{\"fp_table_row\""
    ":{\"maxItems\":2048,\"items\":{\"type\":\"number\"},\"type\":\"array\",\"minItems\":"
    "1},\"fp\":{\"type\":\"object\",\"required\":[\"s\",\"w\"],\"properties\":{\"w\":{\"maxI"
    "tems\":256,\"items\":{\"maxItems\":5,\"items\":{\"type\":\"number\"},\"type\":\"arra"
    "y\",\"minItems\":5},\"type\":\"array\",\"minItems\":1},\"s\":{\"maxItems\":256,\"ite"
    "ms\":{\"maxItems\":4096,\"items\":{\"type\":\"number\"},\"type\":\"array\",\"minItem"
    "s\":1},\"type\":\"array\",\"minItems\":1}},\"description\":\"Fingerprint "
    "values\"},\"fp_table\":{\"type\":\"object\",\"desription\":\"scanner internal da"
    "ta\",\"properties\":{\"ny\":{\"type\":\"integer\",\"max\":2048,\"description\":\"num"
    "ber of y entries\",\"min\":1},\"tv\":{\"maxItems\":2048,\"items\":{\"oneOf\":[{\"$"
    "ref\":\"#/definitions/fp_table_row\"},{\"type\":\"number\"}]},\"type\":\"array\","
    "\"minItems\":1},\"tc\":{\"type\":\"integer\",\"max\":255,\"description\":\"table "
    "data type "
    "code\",\"min\":0},\"ch\":{\"type\":\"integer\",\"max\":255,\"description\":\"channel"
    " number\",\"min\":0},\"nx\":{\"type\":\"integer\",\"max\":2048,\"description\":\"num"
    "ber of x entries\",\"min\":1}},\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"]}},\"d"
    "escription\":\"Receiver Internals\"}"
    ,
    /* example: */
    "{\"ns\":400,\"tbl\":[{\"ny\":2,\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],\"tc\""
    ":1,\"ch\":0,\"nx\":5}],\"sr\":7959997000.0,\"a\":[-1.55],\"nt\":128,\"si\":48,\"mw\""
    ":31,\"t\":{\"1\":{\"w\":[[78,86,126,134,31],[78,86,126,134,31]],\"s\":[[1.23,4"
    ".56],[7.89,0.12]]},\"0\":{\"w\":[[78,86,126,134,31],[78,86,126,134,31]],\"s"
    "\":[[1.23,4.56],[7.89,0.12]]}}}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"delta\",\"content\"],\"title\":\"Reflectance Calculation "
    "Table\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\"},\"content\":{"
    "\"maxItems\":2000,\"items\":{\"type\":\"number\"},\"type\":\"array\",\"minItems\":1,"
    "\"description\":\"Correction value [dB] to be added to the amplitude\"}},\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"de"
    "scription\":\"Lookup table for reflectance calculation based on "
    "amplitude and range\"}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"ranges_m\",\"line_angles_deg\",\"reflectance_correction_db\"]"
    ",\"title\":\"Near-range reflectance correction\",\"properties\":{\"ranges_m\":"
    "{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Range [m]\"},\""
    "line_angles_deg\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"descriptio"
    "n\":\"Angle [deg]\"},\"reflectance_correction_db\":{\"items\":{\"items\":{\"type"
    "\":\"number\",\"description\":\"columns (each value corresponds to an "
    "angle)\"},\"type\":\"array\",\"description\":\"rows (each array corresponds to"
    " a range)\"},\"type\":\"array\",\"description\":\"Near range reflectance "
    "correction in dB as a function of range over angle\"}},\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Ran"
    "ge-dependent and scan-angle-dependent correction of reflectance "
    "reading\"}"
    ,
    /* example: */
    "{\"ranges_m\":[0.0,1.0,2.0,3.0],\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2"
    ".0,2.5,3.0,3.5,4.0],\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,"
    "0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0."
    "8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,"
    "0.1,0.05,0.01]]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Scan Pat"
    "tern\",\"properties\":{\"line\":{\"type\":\"object\",\"required\":[\"start\",\"stop\""
    ",\"increment\"],\"properties\":{\"increment\":{\"minimum\":0.0,\"type\":\"number\""
    ",\"maximum\":90.0,\"description\":\"Increment of angle in SOCS [deg]\"},\"pro"
    "gram\":{\"$ref\":\"#/definitions/program\"},\"stop\":{\"minimum\":0.0,\"type\":\"n"
    "umber\",\"maximum\":720.0,\"description\":\"Stop angle in SOCS [deg]\"},\"star"
    "t\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":360.0,\"description\":\"Start"
    " angle in SOCS [deg]\"}},\"description\":\"Line Scan Pattern\"},\"segments\":"
    "{\"type\":\"object\",\"required\":[\"list\"],\"properties\":{\"list\":{\"items\":{\"t"
    "ype\":\"object\",\"required\":[\"start\",\"stop\",\"increment\"],\"properties\":{\"i"
    "ncrement\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":90.0,\"description\":"
    "\"Increment of angle in SOCS [deg]\"},\"stop\":{\"minimum\":0.0,\"type\":\"numb"
    "er\",\"maximum\":720.0,\"description\":\"Stop angle in SOCS [deg]\"},\"start\":"
    "{\"minimum\":0.0,\"type\":\"number\",\"maximum\":360.0,\"description\":\"Start "
    "angle in SOCS [deg]\"}},\"description\":\"Line Scan Segment\"},\"type\":\"arra"
    "y\"},\"program\":{\"$ref\":\"#/definitions/program\"}},\"description\":\"Segment"
    "ed Line Scan Pattern\"},\"rectangular\":{\"type\":\"object\",\"required\":[\"phi"
    "_start\",\"phi_stop\",\"phi_increment\",\"theta_start\",\"theta_stop\",\"theta_i"
    "ncrement\"],\"properties\":{\"phi_stop\":{\"minimum\":0.0,\"type\":\"number\",\"ma"
    "ximum\":720.0,\"description\":\"Stop phi angle in SOCS [deg]\"},\"phi_increm"
    "ent\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":90.0,\"description\":\"Incr"
    "ement of phi angle in SOCS [deg]\"},\"theta_start\":{\"minimum\":0.0,\"type\""
    ":\"number\",\"maximum\":180.0,\"description\":\"Start theta angle in SOCS [de"
    "g]\"},\"theta_increment\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":90.0,\""
    "description\":\"Increment of theta angle in SOCS [deg]\"},\"theta_stop\":{\""
    "minimum\":0.0,\"type\":\"number\",\"maximum\":180.0,\"description\":\"Stop theta"
    " angle in SOCS [deg]\"},\"program\":{\"$ref\":\"#/definitions/program\"},\"phi"
    "_start\":{\"minimum\":0.0,\"type\":\"number\",\"maximum\":360.0,\"description\":\""
    "Start phi angle in SOCS [deg]\"}},\"description\":\"Rectangular Field Of "
    "View Scan Pattern\"}},\"definitions\":{\"program\":{\"type\":\"object\",\"requir"
    "ed\":[\"name\"],\"properties\":{\"laser_prr\":{\"minimum\":0,\"type\":\"number\",\"e"
    "xclusiveMinimum\":false,\"description\":\"Laser Pulse Repetition Rate "
    "[Hz]\"},\"name\":{\"type\":\"string\",\"description\":\"Name of measurement "
    "program\"}},\"description\":\"Measurement program\"}},\"description\":\"Scan "
    "pattern description\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"phi_stop\":270.0,\"phi_increment\":0.04,\"theta_start\":30"
    ".0,\"theta_increment\":0.04,\"theta_stop\":130.0,\"program\":{\"laser_prr\":10"
    "0000.0,\"name\":\"High Speed\"},\"phi_start\":45.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Shot Inf"
    "ormation\",\"type\":\"object\",\"properties\":{\"shot_file\":{\"type\":\"object\",\""
    "required\":[\"file_extension\"],\"properties\":{\"file_uuid\":{\"type\":\"string"
    "\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading dot\"}}}},\"description\":\"Details about "
    "laser shot files\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"activated\",\"filters\"],\"title\":\"Stored filters\",\"properti"
    "es\":{\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') or "
    "ignore ('false') all filters\"},\"filters\":{\"items\":{\"type\":\"object\",\"re"
    "quired\":[\"activated\",\"title\",\"description\",\"filter\"],\"properties\":{\"ac"
    "tivated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') or ignore "
    "('false') this filter\"},\"title\":{\"type\":\"string\",\"description\":\"A "
    "short filter title (e.g. for display in a selection "
    "list)\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB filter string"
    " to apply (e.g. when reading points or index), details see "
    "documentation of function "
    "select()\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\"}},\"description\":\"Point filter "
    "definition\"},\"type\":\"array\",\"description\":\"List of point filters\"}},\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"des"
    "cription\":\"Point filters applied in addition to the "
    "application-defined filters\"}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"activated\":false,\"title\":\"Ignore "
    "uncertain points from MTA "
    "resolution\",\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"description\":\"Ignore points with uncertain MTA zone "
    "assignment\"},{\"activated\":false,\"title\":\"Ignore points below dynamic "
    "trigger level\",\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"description\":\"Ignore points with an echo signal amplitude below "
    "the dynamic trigger\"},{\"activated\":false,\"title\":\"Ignore points "
    "outside outer AABB\",\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are outside the outer AABB in "
    "BOCS\"},{\"activated\":false,\"title\":\"Ignore points inside inner "
    "AABB\",\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are inside the inner AABB in "
    "BOCS\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"$class\",\"version\",\"author\",\"timestamp\",\"system\"],\"title\""
    ":\"System Description\",\"properties\":{\"author\":{\"type\":\"string\",\"descrip"
    "tion\":\"Name of the author that created the "
    "document\"},\"timestamp\":{\"type\":\"string\",\"description\":\"Date and time "
    "of creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"system\":{\"type\":\"objec"
    "t\",\"description\":\"The actual system description, details see "
    "documentation of RIEGL System Description\"},\"$class\":{\"type\":\"string\","
    "\"enum\":[\"Document\"],\"description\":\"Object class "
    "name\"},\"version\":{\"type\":\"string\",\"description\":\"Document format versi"
    "on\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obje"
    "ct\",\"description\":\"Details of major system components like lidar "
    "sensors, cameras and navigation devices\"}"
    ,
    /* example: */
    "{\"author\":\"RIEGL LMS GmbH, Austria\",\"timestamp\":\"2022-09-30T11:56:26+0"
    "0:00\",\"system\":{\"details\":\"see documentation of RIEGL System "
    "Description\"},\"$class\":\"Document\",\"version\":\"1.2.1\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Temperature Calculation Table\",\"properties\":{\"InGaAs_Si_Diff"
    "erence\":{\"$ref\":\"#/definitions/conversion_table\",\"description\":\"Conver"
    "sion table for InGaAs - Si difference\"},\"InGaAs\":{\"$ref\":\"#/definition"
    "s/conversion_table\",\"description\":\"Conversion table for InGaAs channel"
    "\"},\"Si\":{\"$ref\":\"#/definitions/conversion_table\",\"description\":\"Conver"
    "sion table for Si channel\"}},\"$schema\":\"http://json-schema.org/draft-0"
    "4/schema#\",\"type\":\"object\",\"definitions\":{\"conversion_table\":{\"type\":\""
    "object\",\"required\":[\"value\",\"temperature\"],\"properties\":{\"temperature\""
    ":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Temperature "
    "[\\u00b0C]\"},\"value\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"descrip"
    "tion\":\"LSB [1]\"}}}},\"description\":\"Conversion of background radiation "
    "raw values to temperatures in \\u00b0C\"}"
    ,
    /* example: */
    "{\"InGaAs_Si_Difference\":{\"temperature\":[1749.977111117893,1749.9771111"
    "17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711"
    "1117893,1744.7813348796044,1681.9971312601092,1622.3944822534868],\"val"
    "ue\":[1000.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400"
    ".0885036774805,1500.0427259132668,1600.1327555162209,1700.086977752006"
    "5,1800.0411999877924]},\"InGaAs\":{\"temperature\":[307.22196722535614,309"
    ".1153478247277,311.1188086915047,313.10025350480055,315.2137946389828,"
    "317.2172555057597,319.2207163725366,321.2021611858325,323.315702320014"
    "8],\"value\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,"
    "256.0039063692129,320.00488296151616,384.0058595538194,448.00683614612"
    "26,512.0078127384259]},\"Si\":{\"temperature\":[546.300048828125,548.81640"
    "51212026,551.3143938500972,554.0144257850053,556.604252334815,559.2124"
    "464488079,561.8022729986177,564.4104671126105,567.0002936624203],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"epoch\",\"source\"],\"title\":\"Time "
    "Base\",\"properties\":{\"epoch\":{\"type\":\"string\",\"description\":\"Date and "
    "time of timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:0"
    "0+01:00).\"},\"system\":{\"type\":\"string\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"],\""
    "description\":\"Time system (time standard)\"},\"source\":{\"type\":\"string\","
    "\"enum\":[\"unknown\",\"RTC\",\"GNSS\"],\"description\":\"Timestamp source\"}},\"$s"
    "chema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"desc"
    "ription\":\"Base of timestamps (epoch)\"}"
    ,
    /* example: */
    "{\"epoch\":\"2015-10-27T00:00:00+00:00\",\"system\":\"UTC\",\"source\":\"GNSS\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"time_interval\",\"navigation_frame\"],\"title\":\"Trajectory I"
    "nformation\",\"properties\":{\"company\":{\"type\":\"string\",\"description\":\"Co"
    "mpany name\"},\"field_of_application\":{\"type\":\"string\",\"enum\":[\"unknown\""
    ",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"description\":\"Field"
    " of application\"},\"time_interval\":{\"type\":\"object\",\"required\":[\"minimu"
    "m\",\"average\",\"maximum\",\"std_dev\"],\"properties\":{\"minimum\":{\"type\":\"num"
    "ber\",\"description\":\"Minimum time interval "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard deviation of "
    "intervals [s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time"
    " interval [s]\"}},\"description\":\"Time interval "
    "statistics\"},\"location\":{\"type\":\"string\",\"description\":\"Project "
    "location, e.g. city/state/country\"},\"software\":{\"type\":\"string\",\"descr"
    "iption\":\"Software that calculated the trajectory (this may be the same"
    " or different software than the one that created the "
    "file)\"},\"settings\":{\"type\":\"string\",\"description\":\"Settings used to "
    "calculate the trajectory (descriptive text)\"},\"navigation_frame\":{\"typ"
    "e\":\"string\",\"enum\":[\"unknown\",\"NED\",\"ENU\"],\"description\":\"Navigation "
    "frame (NED: North-East-Down, ENU: "
    "East-North-Up)\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation "
    "device, e.g. "
    "name/type/serial\"},\"project\":{\"type\":\"string\",\"description\":\"Project n"
    "ame\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"obj"
    "ect\",\"description\":\"Details about position+orientation files\"}"
    ,
    /* example: */
    "{\"company\":\"RIEGL LMS\",\"field_of_application\":\"MLS\",\"time_interval\":{\""
    "minimum\":0.00500032,\"average\":0.00500053,\"std_dev\":5.51e-07,\"maximum\":"
    "0.005004883},\"location\":\"Horn\",\"software\":\"Navigation Software "
    "XYZ\",\"settings\":\"default\",\"navigation_frame\":\"NED\",\"device\":\"IMU Model"
    " 12/1, Serial# 12345\",\"project\":\"Campaign 3\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ext_signal\",\""
    "ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"d"
    "mi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\"input_descr"
    "\",\"output_usage\",\"input_usage\",\"out_polarity\",\"out_duration\",\"out_inte"
    "rval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_duration\",\"in"
    "_max_duration\",\"in_max_delay\"],\"title\":\"TTIP Configuration\",\"propertie"
    "s\":{\"ext_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"external "
    "trigger, time delay [0.1 msec]\"},\"out_duration\":{\"minimum\":0,\"type\":\"i"
    "nteger\",\"description\":\"output pulse duration [0.1 msec]\"},\"dmi_max_tim"
    "e\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"dmi, maximum time "
    "interval between trigger events [0.1 msec]\"},\"in_max_delay\":{\"minimum\""
    ":0,\"type\":\"integer\",\"description\":\"maximum delay to output pulse "
    "before fake event is generated [0.1 msec], zero indicates that no fake"
    " events are generated\"},\"dmi_min_time\":{\"minimum\":0,\"type\":\"integer\",\""
    "description\":\"dmi, minimum time interval between trigger events [0.1 "
    "msec]\"},\"ext_channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates "
    "none\"},\"ext_signal\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 .. "
    "use input signal, 1 .. use output signal of channel\"},\"num_channel\":{\""
    "minimum\":0,\"type\":\"integer\",\"description\":\"number of input/output "
    "channels\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative [m]\"},\"out_interval\":{\"minimum\":0,"
    "\"type\":\"integer\",\"description\":\"output pulse interval [0.1 msec]\"},\"in"
    "_min_duration\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"input "
    "signals with smaller pulse durations are ignored [0.1 msec]\"},\"ext_bit"
    "mask\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"defines which of "
    "the internal pulse generators are to be "
    "started\"},\"in_polarity\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0"
    " .. positive edge, 1 .. negative "
    "edge\"},\"out_polarity\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 "
    ".. positive edge, 1 .. negative edge\"},\"out_num_pulses\":{\"minimum\":0,\""
    "type\":\"integer\",\"description\":\"number of output pulses to be "
    "generated, 0 .. "
    "infinite\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"channel\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"ID of "
    "input/output "
    "channel\"},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, increment "
    "in ticks\"},\"ext_subdivider\":{\"minimum\":0,\"type\":\"integer\",\"description"
    "\":\"reduces the frequency, default 1\"},\"ttip_version\":{\"minimum\":0,\"typ"
    "e\":\"integer\",\"description\":\"following main.sub.ss.sss\"},\"output_usage\""
    ":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 .. no output, 1 .. "
    "output derived from internal clock, 2 .. output derived from dmi, 3 .."
    " output derived from external signal, 4 .. output static low, 5 .. "
    "output static "
    "high\"},\"out_delay\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"output"
    " pulse initial delay after start [0.1 msec]\"},\"in_max_duration\":{\"mini"
    "mum\":0,\"type\":\"integer\",\"description\":\"stops measurement of pulse "
    "duration of input signal [0.1 "
    "msec]\"},\"input_usage\":{\"minimum\":0,\"type\":\"integer\",\"description\":\"0 "
    ".. deactivated, 1 .. just detecting and timestamping\"},\"output_descr\":"
    "{\"type\":\"string\",\"description\":\"descriptive string\"}},\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Tri"
    "gger-Timestamping-Unit/IP configuration\"}"
    ,
    /* example: */
    "{\"ext_delay\":0,\"out_duration\":300,\"dmi_max_time\":0,\"in_max_delay\":9990"
    ",\"dmi_min_time\":0,\"ext_channel\":32,\"ext_signal\":0,\"num_channel\":9,\"dmi"
    "_dist_per_tick\":0.0,\"out_interval\":10000,\"in_min_duration\":0,\"ext_bitm"
    "ask\":0,\"in_polarity\":0,\"out_polarity\":0,\"out_num_pulses\":1,\"input_desc"
    "r\":\"Port 1 - Exposure\",\"channel\":0,\"dmi_incr\":0,\"ext_subdivider\":1,\"tt"
    "ip_version\":1,\"output_usage\":1,\"out_delay\":0,\"in_max_duration\":10000,\""
    "input_usage\":1,\"output_descr\":\"Port 1 - Trigger\"}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Vertex I"
    "nformation\",\"type\":\"object\",\"properties\":{\"vertex_file\":{\"type\":\"objec"
    "t\",\"required\":[\"file_extension\"],\"properties\":{\"file_uuid\":{\"type\":\"st"
    "ring\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex file "
    "extension, without the leading dot\"}}}},\"description\":\"Details about "
    "vertex file\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"title\":\"Voxel Information\",\"$schema\":\"http://json-schema.org/draft-0"
    "4/schema#\",\"description\":\"Details about the voxels contained in the fi"
    "le\",\"type\":\"object\",\"definitions\":{\"voxel_origin_enum\":{\"default\":\"cor"
    "ner\",\"enum\":[\"center\",\"corner\"],\"description\":\"Defines whether the "
    "voxel's center or a corner is placed on CRS origin <tt>(0/0/0)</tt>.\"}"
    ",\"shape_thresholds\":{\"type\":\"object\",\"required\":[\"plane\",\"line\"],\"prop"
    "erties\":{\"line\":{\"minimum\":1,\"type\":\"number\",\"exclusiveMinimum\":true,\""
    "description\":\"If the biggest eigenvalue is bigger than the median "
    "eigenvalue * line_threshold, the voxel is considered a line.\"},\"plane\""
    ":{\"exclusiveMaximum\":true,\"exclusiveMinimum\":true,\"maximum\":1,\"minimum"
    "\":0,\"type\":\"number\",\"description\":\"If the smallest eigenvalue is "
    "smaller than the median eigenvalue * plane_threshold, the voxel is "
    "considered a plane.\"}},\"description\":\"Thresholds used to compute the "
    "voxel's shape_id value.\"},\"voxel_size_cubic\":{\"$ref\":\"#/definitions/ed"
    "ge_length\",\"type\":\"number\"},\"voxel_type\":{\"default\":\"centroid\",\"enum\":"
    "[\"center\",\"centroid\",\"index\"],\"description\":\"Whether a point in a "
    "voxel represents its center or its centroid. If type is <tt>index</tt>"
    " there is no point but only an integer voxel index.\"},\"voxel_size\":{\"m"
    "axItems\":3,\"items\":{\"$ref\":\"#/definitions/edge_length\"},\"type\":\"array\""
    ",\"minItems\":3,\"description\":\"Size of voxels.\"},\"voxel_origin_point\":{\""
    "maxItems\":3,\"items\":{\"type\":\"number\"},\"type\":\"array\",\"minItems\":3,\"des"
    "cription\":\"Origin point for all voxel indices in voxel CRS.\"},\"edge_le"
    "ngth\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":true,\"descriptio"
    "n\":\"Length of voxel edge [m].\"}},\"oneOf\":[{\"additionalProperties\":fals"
    "e,\"required\":[\"size\",\"voxel_origin\",\"voxel_type\"],\"properties\":{\"shape"
    "_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel_origin\":"
    "{\"$ref\":\"#/definitions/voxel_origin_enum\"},\"voxel_type\":{\"$ref\":\"#/def"
    "initions/voxel_type\"},\"size\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_si"
    "ze\"},{\"$ref\":\"#/definitions/voxel_size_cubic\"}],\"description\":\"Size of"
    " voxels in file coordinate system.\"}}},{\"additionalProperties\":false,\""
    "required\":[\"reference_point\",\"size_llcs\",\"size\",\"voxel_origin\",\"voxel_"
    "type\"],\"properties\":{\"shape_thresholds\":{\"$ref\":\"#/definitions/shape_t"
    "hresholds\"},\"size_llcs\":{\"$ref\":\"#/definitions/voxel_size\",\"descriptio"
    "n\":\"Size of voxels in a locally levelled cartesian coordinate system "
    "(xyz). This is only used for voxels based on a map projection.\"},\"voxe"
    "l_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"voxel_origin\":{\"oneOf\":[{"
    "\"$ref\":\"#/definitions/voxel_origin_enum\"},{\"$ref\":\"#/definitions/voxel"
    "_origin_point\",\"description\":\"The base point of the voxel grid. Used "
    "together with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute "
    "actual point coordinates.\"}]},\"reference_point\":{\"maxItems\":2,\"items\":"
    "{\"minimum\":-180,\"type\":\"number\",\"maximum\":180},\"type\":\"array\",\"minItem"
    "s\":2,\"description\":\"Point in WGS84 geodetic decimal degree (EPSG:4326)"
    " that was used to compute the projection distortion parameters. The "
    "coefficient order is latitude, longitude. Only voxels with "
    "corresponding geo_tag, voxel_size and reference_point can be reliably "
    "processed together. This entry is available for voxel files in "
    "projected CRS "
    "only.\"},\"size\":{\"$ref\":\"#/definitions/voxel_size\",\"description\":\"Size "
    "of voxels in file coordinate system.\"}}}]}"
    ,
    /* example: */
    "{\"shape_thresholds\":{\"plane\":0.16,\"line\":6},\"size_llcs\":[0.51565752528"
    "91171,0.5130835356683303,0.5143705304787237],\"voxel_type\":\"centroid\",\""
    "voxel_origin\":\"corner\",\"reference_point\":[48,16],\"size\":[0.59716428347"
    "79395,0.5971642834779395,0.5143705304787237]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"num_shots\",\"mta_zone\"],\"title\":\"Waveform Averaging Setti"
    "ngs\",\"properties\":{\"mta_zone\":{\"minimum\":1,\"type\":\"integer\",\"descripti"
    "on\":\"Fixed MTA zone for averaging.\"},\"trim\":{\"minimum\":0,\"type\":\"numbe"
    "r\",\"maximum\":0.5,\"default\":0,\"description\":\"Percentage for robust aver"
    "aging.\"},\"num_shots\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Numb"
    "er of consecutive shots to be used for averaging.\"}},\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"type\":\"object\",\"description\":\"Sett"
    "ings for waveform averaging\"}"
    ,
    /* example: */
    "{\"mta_zone\":1,\"trim\":0.05,\"num_shots\":7}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Waveform Information\",\"properties\":{\"range_o"
    "ffset_waveform_samples_m\":{\"type\":\"number\",\"description\":\"Calibrated "
    "device specific range offset for waveform samples in "
    "meters.\"},\"range_offset_m\":{\"type\":\"number\",\"description\":\"Calibrated "
    "device specific range offset for waveform analysis by system response "
    "fitting in meters.\"},\"sample_block_file\":{\"type\":\"object\",\"required\":["
    "\"file_extension\"],\"properties\":{\"file_uuid\":{\"type\":\"string\",\"descript"
    "ion\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block "
    "file extension, without the leading dot\"}}},\"sample_data_files\":{\"item"
    "s\":{\"type\":\"object\",\"required\":[\"channel\",\"channel_name\",\"sample_inter"
    "val\",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_extension\"],\"pr"
    "operties\":{\"laser_wavelength\":{\"minimum\":0,\"type\":\"number\",\"exclusiveM"
    "inimum\":false,\"description\":\"Laser wavelength in meters (0 = unknown)\""
    "},\"sample_interval\":{\"minimum\":0,\"type\":\"number\",\"exclusiveMinimum\":fa"
    "lse,\"description\":\"Sampling interval in seconds\"},\"sample_bits\":{\"excl"
    "usiveMaximum\":false,\"exclusiveMinimum\":false,\"maximum\":32,\"minimum\":0,"
    "\"type\":\"integer\",\"description\":\"Bitwidth of samples (e.g. 10 bit, 12 "
    "bit)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample data "
    "file extension, without the leading "
    "dot\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"},\"channel\":{\"exclusiveMaximum\":false,\"exclusiveMinimum\":"
    "false,\"maximum\":255,\"minimum\":0,\"type\":\"integer\",\"description\":\"Sample"
    " block channel number (255 = "
    "invalid)\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC 4122)\"},\"delta_st\":{\"type\":\"number\""
    ",\"description\":\"reserved\"}}},\"type\":\"array\"}},\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"required\":[\"sample_block_file\",\"sample_da"
    "ta_files\"],\"description\":\"Details about waveform files\"}"
    ,
    /* example: */
    "{\"range_offset_m\":3.1415,\"sample_data_files\":[{\"laser_wavelength\":0,\"s"
    "ample_interval\":1.00503e-09,\"sample_bits\":12,\"file_extension\":\"sp0\",\"c"
    "hannel_name\":\"high_power\",\"channel\":0,\"file_uuid\":\"da084413-e3e8-4655-"
    "a122-071de8490d8e\",\"delta_st\":0},{\"laser_wavelength\":0,\"sample_interva"
    "l\":1.00503e-09,\"sample_bits\":12,\"file_extension\":\"sp1\",\"channel_name\":"
    "\"low_power\",\"channel\":1,\"file_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be64"
    "2d2\",\"delta_st\":0},{\"laser_wavelength\":0,\"sample_interval\":1.00503e-09"
    ",\"sample_bits\":12,\"file_extension\":\"sp5\",\"channel_name\":\"wwf\",\"channel"
    "\":5,\"file_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\",\"delta_st\":0}],"
    "\"sample_block_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660"
    "\",\"file_extension\":\"sbx\"},\"range_offset_waveform_samples_m \":7.283}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"items\":{\"type\":\"object\",\"required\":[\"sbl_name\",\"enabled\",\"channel_id"
    "x_mask\"],\"properties\":{\"pass_dev_less\":{\"type\":\"integer\",\"description\""
    ":\"Threshold for deviation less than "
    "[1]\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "range less than "
    "[m]\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output enabl"
    "ed\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold for"
    " deviation greater than "
    "[1]\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude less than "
    "[dB]\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for range greater than "
    "[m]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform "
    "output enabled\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of "
    "sample block, e.g.: wfm, "
    "wwf\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\"}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"tit"
    "le\":\"Waveform Settings\",\"type\":\"array\",\"description\":\"Scanner settings"
    " for waveform output\"}"
    ,
    /* example: */
    "[{\"pass_ampl_greater\":1.0,\"pass_rng_less\":13.11,\"enabled\":true,\"pass_a"
    "mpl_less\":5.0,\"pass_rng_greater\":9.27,\"smart_enabled\":true,\"sbl_name\":"
    "\"wfm\",\"channel_idx_mask\":11},{\"sbl_name\":\"wwf\",\"enabled\":false,\"channe"
    "l_idx_mask\":32}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"result\",\"filter\",\"settings\"],\"title\":\"Window Analysis\",\""
    "properties\":{\"settings\":{\"type\":\"object\",\"required\":[\"range\",\"amplitud"
    "e\"],\"properties\":{\"amplitude\":{\"type\":\"object\",\"required\":[\"sigma_fact"
    "or\",\"additive_value\"],\"properties\":{\"additive_value\":{\"type\":\"number\"}"
    ",\"sigma_factor\":{\"type\":\"number\"}}},\"range\":{\"type\":\"object\",\"required"
    "\":[\"sigma_factor\",\"additive_value\"],\"properties\":{\"additive_value\":{\"t"
    "ype\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}}}}},\"result\":{\"type\":\""
    "object\",\"required\":[\"angle\",\"range_mean\",\"range_sigma\",\"amplitude_mean"
    "\",\"amplitude_sigma\",\"amplitude_offset\"],\"properties\":{\"amplitude_mean\""
    ":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"[dB]\"},\"time"
    "stamp\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"[s]\"},"
    "\"amplitude_offset\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"descript"
    "ion\":\"[dB]\"},\"range_mean\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"d"
    "escription\":\"[m]\"},\"range_sigma\":{\"items\":{\"type\":\"number\"},\"type\":\"ar"
    "ray\",\"description\":\"[m]\"},\"amplitude_sigma\":{\"items\":{\"type\":\"number\"}"
    ",\"type\":\"array\",\"description\":\"[dB]\"},\"angle\":{\"items\":{\"type\":\"number"
    "\"},\"type\":\"array\",\"description\":\"[deg]\"}}},\"filter\":{\"type\":\"object\",\""
    "required\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_max\"],\"propertie"
    "s\":{\"amplitude_max\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"descrip"
    "tion\":\"[dB]\"},\"range_max\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"d"
    "escription\":\"[m]\"},\"range_min\":{\"items\":{\"type\":\"number\"},\"type\":\"arra"
    "y\",\"description\":\"[m]\"},\"angle\":{\"items\":{\"type\":\"number\"},\"type\":\"arr"
    "ay\",\"description\":\"[deg]\"}}}},\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"type\":\"object\",\"description\":\"Window analysis data "
    "estimated from scandata and resulting filter parameters\"}"
    ,
    /* example: */
    "{\"settings\":{\"amplitude\":{\"additive_value\":1.0,\"sigma_factor\":4},\"rang"
    "e\":{\"additive_value\":0.1,\"sigma_factor\":8}},\"result\":{\"amplitude_mean\""
    ":[5.347396,5.263155,5.224655,5.179926,5.097782,5.116479,5.051756,4.983"
    "473,5.007885,5.002441,4.982],\"timestamp\":[408.4441,411.4443],\"amplitud"
    "e_offset\":[1.9,1.9],\"range_mean\":[0.1105621,0.1079564,0.1087088,0.1067"
    "261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.1058445,0.10312"
    "61],\"range_sigma\":[0.01869652,0.02151435,0.01747969,0.01918765,0.01945"
    "776,0.01934862,0.01955329,0.02225589,0.02229977,0.01899122,0.02009433]"
    ",\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,"
    "0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],\"angle\":["
    "14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9]},\"filter\":{\"am"
    "plitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78],\"r"
    "ange_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.431,0.431,"
    "0.432],\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0"
    ".221,-0.223,-0.225,-0.227],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5"
    ",15.6,15.7,15.8,15.9]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"required\":[\"amplitude\",\"range\",\"slices\"],\"title\":\"Window Echo Correc"
    "tion\",\"properties\":{\"amplitude\":{\"type\":\"object\",\"required\":[\"minimum\""
    ",\"maximum\",\"entries\"],\"properties\":{\"minimum\":{\"minimum\":0.0,\"type\":\"n"
    "umber\",\"description\":\"Minimum amplitude in "
    "dB\"},\"entries\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number of "
    "amplitude entries\"},\"maximum\":{\"minimum\":0.0,\"type\":\"number\",\"descript"
    "ion\":\"Maximum amplitude in dB\"}},\"description\":\"Amplitude axis of "
    "correction table\"},\"range\":{\"type\":\"object\",\"required\":[\"minimum\",\"max"
    "imum\",\"entries\"],\"properties\":{\"minimum\":{\"minimum\":-2.0,\"type\":\"numbe"
    "r\",\"maximum\":2.0,\"description\":\"Minimum range in "
    "m\"},\"entries\":{\"minimum\":1,\"type\":\"integer\",\"description\":\"Number of "
    "range entries\"},\"maximum\":{\"minimum\":-2.0,\"type\":\"number\",\"maximum\":2."
    "0,\"description\":\"Maximum range in m\"}},\"description\":\"Range axis of "
    "correction table\"},\"slices\":{\"items\":{\"type\":\"object\",\"required\":[\"amp"
    "litude\",\"table\"],\"properties\":{\"amplitude\":{\"type\":\"number\",\"descripti"
    "on\":\"Window echo amplitude of slice in dB\"},\"table\":{\"items\":{\"items\":"
    "{\"maxItems\":3,\"items\":{\"type\":\"number\",\"description\":\"Table cell (item"
    " 0: amplitude in dB, 1: range in m, 2: "
    "flags)\"},\"type\":\"array\",\"minItems\":3,\"description\":\"Table column (= "
    "range axis)\"},\"type\":\"array\",\"minItems\":1,\"description\":\"Table row (= "
    "amplitude "
    "axis)\"},\"type\":\"array\",\"minItems\":1,\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' "
    "objects)\"}},\"description\":\"Window echo correction parameter slice\"},\"t"
    "ype\":\"array\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"ty"
    "pe\":\"object\",\"description\":\"Correction parameters for window glass "
    "echoes\"}"
    ,
    /* example: */
    "{\"amplitude\":{\"minimum\":2,\"entries\":128,\"maximum\":20},\"range\":{\"minimu"
    "m\":-1.5060822940732335,\"entries\":128,\"maximum\":1.5060822940732335},\"sl"
    "ices\":[{\"amplitude\":1.5,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]"
    "},{\"amplitude\":2.0,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}]}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);

#endif // RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
